@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+import logging
 import os
+import sys
 
 import click
 
@@ -9,18 +11,29 @@ from newschimp.social import fb, gg, lanyrd
 from newschimp.cli import cli_group
 from newschimp.utils import ComplexCLI, load_settings
 
+LOGGER = logging.getLogger(__name__)
+
 
 def create_newsletter(settings):
     """Newsletter creation based on config and env variables"""
     context = {}
-    fb_posts = fb.get_posts(settings, os.environ.get('FACEBOOK_TOKEN'), None)
+    try:
+        fb_posts = fb.get_posts(settings, os.environ['FACEBOOK_TOKEN'], None)
+    except KeyError:
+        LOGGER.error('Facebook Token not defined')
+        sys.exit()
+    click.echo('[1/4] Getting Facebook Group posts')
     context['fb'] = fb.curate(fb_posts)
     ggroup_posts = gg.get_posts(settings, None)
+    click.echo('[2/4] Getting Google Group posts')
     context['gg'] = gg.curate(ggroup_posts)
+    click.echo('[3/4] Getting upcoming Lanyrd meetups')
     context['meetups'] = lanyrd.meetup_loop(settings)
+    click.echo('[4/4] Rendering mail')
     renderer.render_files(settings, None, context)
     click.confirm(
         'Content is rendered, would you like to send it now?', abort=True)
+    click.echo('Creating MailChimp campaign')
     sender.new_campaign(settings, os.environ.get('MAILCHIMP_KEY'))
 
 
